ScheduleBuildError

Enum ScheduleBuildError 

#[non_exhaustive]
pub enum ScheduleBuildError { HierarchySort(DiGraphToposortError<NodeId>), DependencySort(DiGraphToposortError<NodeId>), FlatDependencySort(DiGraphToposortError<SystemKey>), CrossDependency(DagCrossDependencyError<NodeId>), SetsHaveOrderButIntersect(DagOverlappingGroupError<SystemSetKey>), SystemTypeSetAmbiguity(SystemTypeSetAmbiguityError), Uninitialized, Elevated(ScheduleBuildWarning), }
Category of errors encountered during Schedule::initialize.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


HierarchySort(DiGraphToposortError<NodeId>)

Tried to topologically sort the hierarchy of system sets.



DependencySort(DiGraphToposortError<NodeId>)

Tried to topologically sort the dependency graph.



FlatDependencySort(DiGraphToposortError<SystemKey>)

Tried to topologically sort the flattened dependency graph.



CrossDependency(DagCrossDependencyError<NodeId>)

Tried to order a system (set) relative to a system set it belongs to.



SetsHaveOrderButIntersect(DagOverlappingGroupError<SystemSetKey>)

Tried to order system sets that share systems.



SystemTypeSetAmbiguity(SystemTypeSetAmbiguityError)

Tried to order a system (set) relative to all instances of some system function.



Uninitialized

Tried to run a schedule before all of its systems have been initialized.



Elevated(ScheduleBuildWarning)

A warning that was elevated to an error.

Implementations



impl ScheduleBuildError

pub fn to_string(&self, graph: &ScheduleGraph, world: &World) -> String

Renders the error as a human-readable string with node identifiers replaced with their names.

The given graph and world are used to resolve the names of the nodes and components involved in the error. The same graph and world should be used as those used to initialize the Schedule. Failure to do so will result in incorrect or incomplete error messages.