Enum ScheduleBuildWarning
#[non_exhaustive]pub enum ScheduleBuildWarning {
HierarchyRedundancy(DagRedundancyError<NodeId>),
Ambiguity(AmbiguousSystemConflictsWarning),
}Expand description
Category of warnings encountered during Schedule::initialize.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
HierarchyRedundancy(DagRedundancyError<NodeId>)
The hierarchy of system sets contains redundant edges.
This warning is enabled by default, but can be disabled by setting
ScheduleBuildSettings::hierarchy_detection to LogLevel::Ignore
or upgraded to a ScheduleBuildError by setting it to LogLevel::Error.
Ambiguity(AmbiguousSystemConflictsWarning)
Systems with conflicting access have indeterminate run order.
This warning is disabled by default, but can be enabled by setting
ScheduleBuildSettings::ambiguity_detection to LogLevel::Warn
or upgraded to a ScheduleBuildError by setting it to LogLevel::Error.
Implementations
impl ScheduleBuildWarning
impl ScheduleBuildWarning
pub fn to_string(&self, graph: &ScheduleGraph, world: &World) -> String
pub fn to_string(&self, graph: &ScheduleGraph, world: &World) -> String
Renders the warning as a human-readable string with node identifiers replaced with their names.