Enum ScheduleCleanupPolicy
pub enum ScheduleCleanupPolicy {
RemoveSetAndSystems,
RemoveSystemsOnly,
RemoveSetAndSystemsAllowBreakages,
RemoveSystemsOnlyAllowBreakages,
}Expand description
Policy to use when removing systems.
Variants
RemoveSetAndSystems
Remove the referenced set and any systems in the set. Attempts to maintain the order between the transitive dependencies by adding new edges between the existing before and after dependencies on the set and the systems. This does not remove sets that might sub sets of the set.
RemoveSystemsOnly
Remove only the systems in the set. The set Attempts to maintain the order between the transitive dependencies by adding new edges between the existing before and after dependencies on the systems.
RemoveSetAndSystemsAllowBreakages
Remove the set and any systems in the set. Note that this will not add new edges and so will break any transitive dependencies on that set or systems. This does not remove sets that might sub sets of the set.
RemoveSystemsOnlyAllowBreakages
Remove only the systems in the set. Note that this will not add new edges and so will break any transitive dependencies on that set or systems.