Struct Schedule
pub struct Schedule { /* private fields */ }Expand description
A collection of systems, and the metadata and executor needed to run them in a certain order under certain conditions.
Schedule labels
Each schedule has a ScheduleLabel value. This value is used to uniquely identify the
schedule when added to a World’s Schedules, and may be used to specify which schedule
a system should be added to.
Example
Here is an example of a Schedule running a “Hello world” system:
fn hello_world() { println!("Hello world!") }
fn main() {
let mut world = World::new();
let mut schedule = Schedule::default();
schedule.add_systems(hello_world);
schedule.run(&mut world);
}A schedule can also run several systems in an ordered way:
fn system_one() { println!("System 1 works!") }
fn system_two() { println!("System 2 works!") }
fn system_three() { println!("System 3 works!") }
fn main() {
let mut world = World::new();
let mut schedule = Schedule::default();
schedule.add_systems((
system_two,
system_one.before(system_two),
system_three.after(system_two),
));
schedule.run(&mut world);
}Schedules are often inserted into a World and identified by their ScheduleLabel only:
use bevy_ecs::schedule::ScheduleLabel;
// Declare a new schedule label.
#[derive(ScheduleLabel, Clone, Debug, PartialEq, Eq, Hash, Default)]
struct Update;
// This system shall be part of the schedule.
fn an_update_system() {
println!("Hello world!");
}
fn main() {
let mut world = World::new();
// Add a system to the schedule with that label (creating it automatically).
world.get_resource_or_init::<Schedules>().add_systems(Update, an_update_system);
// Run the schedule, and therefore run the system.
world.run_schedule(Update);
}Implementations
impl Schedule
impl Schedule
pub fn new(label: impl ScheduleLabel) -> Schedule
pub fn new(label: impl ScheduleLabel) -> Schedule
Constructs an empty Schedule.
pub fn is_changed(&self) -> bool
pub fn is_changed(&self) -> bool
Returns whether this schedule has been changed since the last time it was built.
pub fn label(&self) -> Interned<dyn ScheduleLabel>
pub fn label(&self) -> Interned<dyn ScheduleLabel>
Returns the InternedScheduleLabel for this Schedule,
corresponding to the ScheduleLabel this schedule was created with.
pub fn add_systems<M>(
&mut self,
systems: impl IntoScheduleConfigs<Box<dyn System<Out = (), In = ()>>, M>,
) -> &mut Schedule
pub fn add_systems<M>( &mut self, systems: impl IntoScheduleConfigs<Box<dyn System<Out = (), In = ()>>, M>, ) -> &mut Schedule
Add a collection of systems to the schedule.
pub fn remove_systems_in_set<M>(
&mut self,
set: impl IntoSystemSet<M>,
world: &mut World,
policy: ScheduleCleanupPolicy,
) -> Result<usize, ScheduleError>
pub fn remove_systems_in_set<M>( &mut self, set: impl IntoSystemSet<M>, world: &mut World, policy: ScheduleCleanupPolicy, ) -> Result<usize, ScheduleError>
Removes all systems in a SystemSet. This will cause the schedule to be rebuilt when
the schedule is run again. A ScheduleError is returned if the schedule needs to be
Schedule::initialize’d or the set is not found.
Note that this can remove all systems of a type if you pass the system to this function as systems implicitly create a set based on the system type.
Example
let mut schedule = Schedule::default();
// add the system to the schedule
schedule.add_systems(my_system);
let mut world = World::default();
// remove the system
schedule.remove_systems_in_set(my_system, &mut world, ScheduleCleanupPolicy::RemoveSystemsOnly);pub fn ignore_ambiguity<M1, M2, S1, S2>(
&mut self,
a: S1,
b: S2,
) -> &mut Schedulewhere
S1: IntoSystemSet<M1>,
S2: IntoSystemSet<M2>,
pub fn ignore_ambiguity<M1, M2, S1, S2>(
&mut self,
a: S1,
b: S2,
) -> &mut Schedulewhere
S1: IntoSystemSet<M1>,
S2: IntoSystemSet<M2>,
Suppress warnings and errors that would result from systems in these sets having ambiguities
(conflicting access but indeterminate order) with systems in set.
pub fn configure_sets<M>(
&mut self,
sets: impl IntoScheduleConfigs<Interned<dyn SystemSet>, M>,
) -> &mut Schedule
pub fn configure_sets<M>( &mut self, sets: impl IntoScheduleConfigs<Interned<dyn SystemSet>, M>, ) -> &mut Schedule
Configures a collection of system sets in this schedule, adding them if they does not exist.
pub fn add_build_pass<T>(&mut self, pass: T) -> &mut Schedulewhere
T: ScheduleBuildPass,
pub fn add_build_pass<T>(&mut self, pass: T) -> &mut Schedulewhere
T: ScheduleBuildPass,
Add a custom build pass to the schedule.
pub fn remove_build_pass<T>(&mut self)where
T: ScheduleBuildPass,
pub fn remove_build_pass<T>(&mut self)where
T: ScheduleBuildPass,
Remove a custom build pass.
pub fn set_build_settings(
&mut self,
settings: ScheduleBuildSettings,
) -> &mut Schedule
pub fn set_build_settings( &mut self, settings: ScheduleBuildSettings, ) -> &mut Schedule
Changes miscellaneous build settings.
If settings.auto_insert_apply_deferred
is false, this clears *_ignore_deferred edge settings configured so far.
Generally this method should be used before adding systems or set configurations to the schedule, not after.
pub fn get_build_settings(&self) -> ScheduleBuildSettings
pub fn get_build_settings(&self) -> ScheduleBuildSettings
Returns the schedule’s current ScheduleBuildSettings.
pub fn set_executor(
&mut self,
executor: impl SystemExecutor + 'static,
) -> &mut Schedule
pub fn set_executor( &mut self, executor: impl SystemExecutor + 'static, ) -> &mut Schedule
Replaces the schedule’s executor.
pub fn set_apply_final_deferred(
&mut self,
apply_final_deferred: bool,
) -> &mut Schedule
pub fn set_apply_final_deferred( &mut self, apply_final_deferred: bool, ) -> &mut Schedule
Set whether the schedule applies deferred system buffers on final time or not. This is a catch-all
in case a system uses commands but was not explicitly ordered before an instance of
ApplyDeferred. By default this
setting is true, but may be disabled if needed.
pub fn run(&mut self, world: &mut World)
pub fn run(&mut self, world: &mut World)
Runs all systems in this schedule on the world, using its current execution strategy.
pub fn initialize(
&mut self,
world: &mut World,
) -> Result<Option<ScheduleBuildMetadata>, ScheduleBuildError>
pub fn initialize( &mut self, world: &mut World, ) -> Result<Option<ScheduleBuildMetadata>, ScheduleBuildError>
Initializes any newly-added systems and conditions, rebuilds the executable schedule, and re-initializes the executor.
Moves all systems and run conditions out of the ScheduleGraph. If the schedule is built
successfully, returns Some with the metadata. If the schedule has previously been built
successfully, returns None.
pub fn graph(&self) -> &ScheduleGraph
pub fn graph(&self) -> &ScheduleGraph
Returns the ScheduleGraph.
pub fn graph_mut(&mut self) -> &mut ScheduleGraph
pub fn graph_mut(&mut self) -> &mut ScheduleGraph
Returns a mutable reference to the ScheduleGraph.
pub fn check_change_ticks(&mut self, check: CheckChangeTicks)
pub fn check_change_ticks(&mut self, check: CheckChangeTicks)
Iterates the change ticks of all systems in the schedule and clamps any older than
MAX_CHANGE_AGE.
This prevents overflow and thus prevents false positives.
pub fn apply_deferred(&mut self, world: &mut World)
pub fn apply_deferred(&mut self, world: &mut World)
Directly applies any accumulated Deferred system parameters (like Commands) to the world.
Like always, deferred system parameters are applied in the “topological sort order” of the schedule graph. As a result, buffers from one system are only guaranteed to be applied before those of other systems if there is an explicit system ordering between the two systems.
This is used in rendering to extract data from the main world, storing the data in system buffers, before applying their buffers in a different world.
pub fn systems(
&self,
) -> Result<impl Iterator<Item = (SystemKey, &Box<dyn System<Out = (), In = ()>>)>, ScheduleNotInitialized>
pub fn systems( &self, ) -> Result<impl Iterator<Item = (SystemKey, &Box<dyn System<Out = (), In = ()>>)>, ScheduleNotInitialized>
Returns an iterator over all systems in this schedule.
Note: this method will return ScheduleNotInitialized if the
schedule has never been initialized or run.
pub fn systems_len(&self) -> usize
pub fn systems_len(&self) -> usize
Returns the number of systems in this schedule.