Struct ScheduleBuildSettings
pub struct ScheduleBuildSettings {
pub ambiguity_detection: LogLevel,
pub hierarchy_detection: LogLevel,
pub auto_insert_apply_deferred: bool,
pub use_shortnames: bool,
pub report_sets: bool,
}Expand description
Specifies miscellaneous settings for schedule construction.
Fields
ambiguity_detection: LogLevelDetermines whether the presence of ambiguities (systems with conflicting access but indeterminate order)
is only logged or also results in an Ambiguity error.
Defaults to LogLevel::Ignore.
hierarchy_detection: LogLevelDetermines whether the presence of redundant edges in the hierarchy of system sets is only
logged or also results in a HierarchyRedundancy
error.
Defaults to LogLevel::Warn.
auto_insert_apply_deferred: boolAuto insert apply_deferred systems into the schedule,
when there are Deferred
in one system and there are ordering dependencies on that system. Commands is one
such deferred buffer.
You may want to disable this if you only want to sync deferred params at the end of the schedule, or want to manually insert all your sync points.
Defaults to true
use_shortnames: boolIf set to true, node names will be shortened instead of the fully qualified type path.
Defaults to true.
report_sets: boolIf set to true, report all system sets the conflicting systems are part of.
Defaults to true.
Implementations
impl ScheduleBuildSettings
impl ScheduleBuildSettings
pub const fn new() -> ScheduleBuildSettings
pub const fn new() -> ScheduleBuildSettings
Default build settings. See the field-level documentation for the default value of each field.