ScheduleGraph

Struct ScheduleGraph 

pub struct ScheduleGraph {
    pub systems: Systems,
    pub system_sets: SystemSets,
    pub ambiguous_with_all: HashSet<NodeId>,
    /* private fields */
}
Metadata for a Schedule.

The order isn’t optimized; calling ScheduleGraph::build_schedule will return a SystemSchedule where the order is optimized for execution.

Fields

systems: Systems

Container of systems in the schedule.

system_sets: SystemSets

Container of system sets in the schedule.

ambiguous_with_all: HashSet<NodeId>

Nodes that are allowed to have ambiguous ordering relationship with any other systems.

Implementations



impl ScheduleGraph

pub fn new() -> ScheduleGraph

Creates an empty ScheduleGraph with default settings.

pub fn hierarchy(&self) -> &Dag<NodeId>

Returns the Dag of the hierarchy.

The hierarchy is a directed acyclic graph of the systems and sets, where an edge denotes that a system or set is the child of another set.

pub fn dependency(&self) -> &Dag<NodeId>

Returns the Dag of the dependencies in the schedule.

Nodes in this graph are systems and sets, and edges denote that a system or set has to run before another system or set.

pub fn conflicting_systems(&self) -> &ConflictingSystems

Returns the list of systems that conflict with each other, i.e. have ambiguities in their access.

If the Vec<ComponentId> is empty, the systems conflict on World access. Must be called after ScheduleGraph::build_schedule to be non-empty.

pub fn systems_in_set( &self, system_set: Interned<dyn SystemSet>, ) -> Result<&IndexSet<SystemKey, FixedHasher>, ScheduleError>

Returns a Vec containing all SystemKeys in a SystemSet.

Errors

This method may return an error. It’ll be:

  • ScheduleError::Uninitialized if the schedule has been changed, and Self::initialize has not been called.
  • ScheduleError::NotFound if system_set isn’t present in the schedule.

pub fn remove_systems_in_set<M>( &mut self, system_set: impl IntoSystemSet<M>, policy: ScheduleCleanupPolicy, ) -> Result<usize, ScheduleError>

Remove all systems in a set and any dependencies on those systems and set.

pub fn initialize(&mut self, world: &mut World)

Initializes any newly-added systems and conditions by calling System::initialize.

pub fn build_schedule( &mut self, world: &mut World, ignored_ambiguities: &BTreeSet<ComponentId>, ) -> Result<(SystemSchedule, ScheduleBuildMetadata), ScheduleBuildError>

Builds an execution-optimized SystemSchedule from the current state of the graph. Also returns any warnings that were generated during the build process.

This method also

  • checks for dependency or hierarchy cycles
  • checks for system access conflicts and reports ambiguities


impl ScheduleGraph

pub fn get_node_name(&self, id: &NodeId) -> String

Returns the name of the node with the given NodeId. Resolves anonymous sets to a string that describes their contents.

Also displays the set(s) the node is contained in if ScheduleBuildSettings::report_sets is true, and shortens system names if ScheduleBuildSettings::use_shortnames is true.