Struct Schedules
pub struct Schedules {
pub ignored_scheduling_ambiguities: BTreeSet<ComponentId>,
/* private fields */
}Expand description
Resource that stores Schedules mapped to ScheduleLabels excluding the current running Schedule.
Fields
ignored_scheduling_ambiguities: BTreeSet<ComponentId>List of ComponentIds to ignore when reporting system order ambiguity conflicts
Implementations
impl Schedules
impl Schedules
pub fn insert(&mut self, schedule: Schedule) -> Option<Schedule>
pub fn insert(&mut self, schedule: Schedule) -> Option<Schedule>
Inserts a labeled schedule into the map.
If the map already had an entry for label, schedule is inserted,
and the old schedule is returned. Otherwise, None is returned.
pub fn remove(&mut self, label: impl ScheduleLabel) -> Option<Schedule>
pub fn remove(&mut self, label: impl ScheduleLabel) -> Option<Schedule>
Removes the schedule corresponding to the label from the map, returning it if it existed.
pub fn remove_entry(
&mut self,
label: impl ScheduleLabel,
) -> Option<(Interned<dyn ScheduleLabel>, Schedule)>
pub fn remove_entry( &mut self, label: impl ScheduleLabel, ) -> Option<(Interned<dyn ScheduleLabel>, Schedule)>
Removes the (schedule, label) pair corresponding to the label from the map, returning it if it existed.
pub fn contains(&self, label: impl ScheduleLabel) -> bool
pub fn contains(&self, label: impl ScheduleLabel) -> bool
Does a schedule with the provided label already exist?
pub fn get(&self, label: impl ScheduleLabel) -> Option<&Schedule>
pub fn get(&self, label: impl ScheduleLabel) -> Option<&Schedule>
Returns a reference to the schedule associated with label, if it exists.
pub fn get_mut(&mut self, label: impl ScheduleLabel) -> Option<&mut Schedule>
pub fn get_mut(&mut self, label: impl ScheduleLabel) -> Option<&mut Schedule>
Returns a mutable reference to the schedule associated with label, if it exists.
pub fn entry(&mut self, label: impl ScheduleLabel) -> &mut Schedule
pub fn entry(&mut self, label: impl ScheduleLabel) -> &mut Schedule
Returns a mutable reference to the schedules associated with label, creating one if it doesn’t already exist.
pub fn iter(
&self,
) -> impl Iterator<Item = (&(dyn ScheduleLabel + 'static), &Schedule)>
pub fn iter( &self, ) -> impl Iterator<Item = (&(dyn ScheduleLabel + 'static), &Schedule)>
Returns an iterator over all schedules. Iteration order is undefined.
pub fn iter_mut(
&mut self,
) -> impl Iterator<Item = (&(dyn ScheduleLabel + 'static), &mut Schedule)>
pub fn iter_mut( &mut self, ) -> impl Iterator<Item = (&(dyn ScheduleLabel + 'static), &mut Schedule)>
Returns an iterator over mutable references to all schedules. Iteration order is undefined.
pub fn configure_schedules(
&mut self,
schedule_build_settings: ScheduleBuildSettings,
)
pub fn configure_schedules( &mut self, schedule_build_settings: ScheduleBuildSettings, )
Applies the provided ScheduleBuildSettings to all schedules.
pub fn allow_ambiguous_component<T>(&mut self, world: &mut World)where
T: Component,
pub fn allow_ambiguous_component<T>(&mut self, world: &mut World)where
T: Component,
Ignore system order ambiguities caused by conflicts on Components of type T.
pub fn allow_ambiguous_resource<T>(&mut self, world: &mut World)where
T: Resource,
pub fn allow_ambiguous_resource<T>(&mut self, world: &mut World)where
T: Resource,
Ignore system order ambiguities caused by conflicts on Resources of type T.
pub fn iter_ignored_ambiguities(&self) -> impl Iterator<Item = &ComponentId>
pub fn iter_ignored_ambiguities(&self) -> impl Iterator<Item = &ComponentId>
Iterate through the ComponentId’s that will be ignored.
pub fn print_ignored_ambiguities(&self, components: &Components)
pub fn print_ignored_ambiguities(&self, components: &Components)
Prints the names of the components and resources with [info]
May panic or retrieve incorrect names if Components is not from the same
world
pub fn add_systems<M>(
&mut self,
schedule: impl ScheduleLabel,
systems: impl IntoSystemConfigs<M>,
) -> &mut Schedules
pub fn add_systems<M>( &mut self, schedule: impl ScheduleLabel, systems: impl IntoSystemConfigs<M>, ) -> &mut Schedules
Adds one or more systems to the Schedule matching the provided ScheduleLabel.
pub fn configure_sets(
&mut self,
schedule: impl ScheduleLabel,
sets: impl IntoSystemSetConfigs,
) -> &mut Schedules
pub fn configure_sets( &mut self, schedule: impl ScheduleLabel, sets: impl IntoSystemSetConfigs, ) -> &mut Schedules
Configures a collection of system sets in the provided schedule, adding any sets that do not exist.
pub fn ignore_ambiguity<M1, M2, S1, S2>(
&mut self,
schedule: impl ScheduleLabel,
a: S1,
b: S2,
) -> &mut Scheduleswhere
S1: IntoSystemSet<M1>,
S2: IntoSystemSet<M2>,
pub fn ignore_ambiguity<M1, M2, S1, S2>(
&mut self,
schedule: impl ScheduleLabel,
a: S1,
b: S2,
) -> &mut Scheduleswhere
S1: IntoSystemSet<M1>,
S2: IntoSystemSet<M2>,
Suppress warnings and errors that would result from systems in these sets having ambiguities
(conflicting access but indeterminate order) with systems in set.
When possible, do this directly in the .add_systems(Update, a.ambiguous_with(b)) call.
However, sometimes two independent plugins A and B are reported as ambiguous, which you
can only suppress as the consumer of both.