Struct Stepping
pub struct Stepping { /* private fields */ }Expand description
Resource for controlling system stepping behavior
Implementations
impl Stepping
impl Stepping
pub fn begin_frame(stepping: Option<ResMut<'_, Stepping>>)
pub fn begin_frame(stepping: Option<ResMut<'_, Stepping>>)
System to call denoting that a new render frame has begun
Note: This system is automatically added to the default MainSchedule.
pub fn schedules(&self) -> Result<&Vec<Interned<dyn ScheduleLabel>>, NotReady>
pub fn schedules(&self) -> Result<&Vec<Interned<dyn ScheduleLabel>>, NotReady>
Return the list of schedules with stepping enabled in the order they are executed in.
pub fn cursor(&self) -> Option<(Interned<dyn ScheduleLabel>, NodeId)>
pub fn cursor(&self) -> Option<(Interned<dyn ScheduleLabel>, NodeId)>
Return our current position within the stepping frame
NOTE: This function will return None during normal execution with
stepping enabled. This can happen at the end of the stepping frame
after the last system has been run, but before the start of the next
render frame.
pub fn add_schedule(&mut self, schedule: impl ScheduleLabel) -> &mut Stepping
pub fn add_schedule(&mut self, schedule: impl ScheduleLabel) -> &mut Stepping
Enable stepping for the provided schedule
pub fn remove_schedule(&mut self, schedule: impl ScheduleLabel) -> &mut Stepping
pub fn remove_schedule(&mut self, schedule: impl ScheduleLabel) -> &mut Stepping
Disable stepping for the provided schedule
NOTE: This function will also clear any system-specific behaviors that may have been configured.
pub fn clear_schedule(&mut self, schedule: impl ScheduleLabel) -> &mut Stepping
pub fn clear_schedule(&mut self, schedule: impl ScheduleLabel) -> &mut Stepping
Clear behavior set for all systems in the provided Schedule
pub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Check if stepping is enabled
pub fn step_frame(&mut self) -> &mut Stepping
pub fn step_frame(&mut self) -> &mut Stepping
Run the next system during the next render frame
NOTE: This will have no impact unless stepping has been enabled
pub fn continue_frame(&mut self) -> &mut Stepping
pub fn continue_frame(&mut self) -> &mut Stepping
Run all remaining systems in the stepping frame during the next render frame
NOTE: This will have no impact unless stepping has been enabled
pub fn always_run<Marker>(
&mut self,
schedule: impl ScheduleLabel,
system: impl IntoSystem<(), (), Marker>,
) -> &mut Stepping
pub fn always_run<Marker>( &mut self, schedule: impl ScheduleLabel, system: impl IntoSystem<(), (), Marker>, ) -> &mut Stepping
Ensure this system always runs when stepping is enabled
Note: if the system is run multiple times in the Schedule, this
will apply for all instances of the system.
pub fn always_run_node(
&mut self,
schedule: impl ScheduleLabel,
node: NodeId,
) -> &mut Stepping
pub fn always_run_node( &mut self, schedule: impl ScheduleLabel, node: NodeId, ) -> &mut Stepping
Ensure this system instance always runs when stepping is enabled
pub fn never_run<Marker>(
&mut self,
schedule: impl ScheduleLabel,
system: impl IntoSystem<(), (), Marker>,
) -> &mut Stepping
pub fn never_run<Marker>( &mut self, schedule: impl ScheduleLabel, system: impl IntoSystem<(), (), Marker>, ) -> &mut Stepping
Ensure this system never runs when stepping is enabled
pub fn never_run_node(
&mut self,
schedule: impl ScheduleLabel,
node: NodeId,
) -> &mut Stepping
pub fn never_run_node( &mut self, schedule: impl ScheduleLabel, node: NodeId, ) -> &mut Stepping
Ensure this system instance never runs when stepping is enabled
pub fn set_breakpoint<Marker>(
&mut self,
schedule: impl ScheduleLabel,
system: impl IntoSystem<(), (), Marker>,
) -> &mut Stepping
pub fn set_breakpoint<Marker>( &mut self, schedule: impl ScheduleLabel, system: impl IntoSystem<(), (), Marker>, ) -> &mut Stepping
Add a breakpoint for system
pub fn set_breakpoint_node(
&mut self,
schedule: impl ScheduleLabel,
node: NodeId,
) -> &mut Stepping
pub fn set_breakpoint_node( &mut self, schedule: impl ScheduleLabel, node: NodeId, ) -> &mut Stepping
Add a breakpoint for system instance
pub fn clear_breakpoint<Marker>(
&mut self,
schedule: impl ScheduleLabel,
system: impl IntoSystem<(), (), Marker>,
) -> &mut Stepping
pub fn clear_breakpoint<Marker>( &mut self, schedule: impl ScheduleLabel, system: impl IntoSystem<(), (), Marker>, ) -> &mut Stepping
Clear a breakpoint for the system
pub fn clear_breakpoint_node(
&mut self,
schedule: impl ScheduleLabel,
node: NodeId,
) -> &mut Stepping
pub fn clear_breakpoint_node( &mut self, schedule: impl ScheduleLabel, node: NodeId, ) -> &mut Stepping
clear a breakpoint for system instance
pub fn clear_system<Marker>(
&mut self,
schedule: impl ScheduleLabel,
system: impl IntoSystem<(), (), Marker>,
) -> &mut Stepping
pub fn clear_system<Marker>( &mut self, schedule: impl ScheduleLabel, system: impl IntoSystem<(), (), Marker>, ) -> &mut Stepping
Clear any behavior set for the system
pub fn clear_node(
&mut self,
schedule: impl ScheduleLabel,
node: NodeId,
) -> &mut Stepping
pub fn clear_node( &mut self, schedule: impl ScheduleLabel, node: NodeId, ) -> &mut Stepping
clear a breakpoint for system instance
pub fn skipped_systems(&mut self, schedule: &Schedule) -> Option<FixedBitSet>
pub fn skipped_systems(&mut self, schedule: &Schedule) -> Option<FixedBitSet>
get the list of systems this schedule should skip for this render frame