Struct SystemSets
pub struct SystemSets { /* private fields */ }Expand description
Container for system sets in a schedule.
Implementations
impl SystemSets
impl SystemSets
pub fn contains(&self, set: impl SystemSet) -> bool
pub fn contains(&self, set: impl SystemSet) -> bool
Returns true if the given set is present in this container.
pub fn get(&self, key: SystemSetKey) -> Option<&(dyn SystemSet + 'static)>
pub fn get(&self, key: SystemSetKey) -> Option<&(dyn SystemSet + 'static)>
Returns a reference to the system set with the given key, if it exists.
pub fn get_key(&self, set: Interned<dyn SystemSet>) -> Option<SystemSetKey>
pub fn get_key(&self, set: Interned<dyn SystemSet>) -> Option<SystemSetKey>
Returns the key for the given system set, returns None if it does not exist.
pub fn get_key_or_insert(
&mut self,
set: Interned<dyn SystemSet>,
) -> SystemSetKey
pub fn get_key_or_insert( &mut self, set: Interned<dyn SystemSet>, ) -> SystemSetKey
Returns the key for the given system set, inserting it into this container if it does not already exist.
pub fn has_conditions(&self, key: SystemSetKey) -> bool
pub fn has_conditions(&self, key: SystemSetKey) -> bool
Returns true if the system set with the given key has conditions.
pub fn get_conditions(
&self,
key: SystemSetKey,
) -> Option<&[ConditionWithAccess]>
pub fn get_conditions( &self, key: SystemSetKey, ) -> Option<&[ConditionWithAccess]>
Returns a reference to the conditions for the system set with the given key, if it exists.
pub fn get_conditions_mut(
&mut self,
key: SystemSetKey,
) -> Option<&mut Vec<ConditionWithAccess>>
pub fn get_conditions_mut( &mut self, key: SystemSetKey, ) -> Option<&mut Vec<ConditionWithAccess>>
Returns a mutable reference to the conditions for the system set with the given key, if it exists.
pub fn iter(
&self,
) -> impl Iterator<Item = (SystemSetKey, &(dyn SystemSet + 'static), &[ConditionWithAccess])>
pub fn iter( &self, ) -> impl Iterator<Item = (SystemSetKey, &(dyn SystemSet + 'static), &[ConditionWithAccess])>
Returns an iterator over all system sets in this container, along with their conditions.
pub fn insert(
&mut self,
set: Interned<dyn SystemSet>,
new_conditions: Vec<Box<dyn ReadOnlySystem<Out = bool, In = ()>>>,
) -> SystemSetKey
pub fn insert( &mut self, set: Interned<dyn SystemSet>, new_conditions: Vec<Box<dyn ReadOnlySystem<Out = bool, In = ()>>>, ) -> SystemSetKey
Inserts conditions for a system set into the container, and queues the
newly added conditions to be initialized later in SystemSets::initialize.
If the set was not already present in the container, it is added automatically.
We have to defer initialization of system set conditions in the container
until we have &mut World access, so we store these in a list until
SystemSets::initialize is called. This is usually done upon the
first run of the schedule.
pub fn is_initialized(&self) -> bool
pub fn is_initialized(&self) -> bool
Returns true if all system sets’ conditions in this container have
been initialized.
pub fn initialize(&mut self, world: &mut World)
pub fn initialize(&mut self, world: &mut World)
Initializes all system sets’ conditions that have not been initialized yet. Because a system set’s conditions may be appended to multiple times, we track which conditions were added since the last initialization and only initialize those.
pub fn check_type_set_ambiguity(
&self,
set_systems: &DagGroups<SystemSetKey, SystemKey>,
ambiguous_with: &Graph<false, NodeId>,
dependency: &Graph<true, NodeId>,
) -> Result<(), SystemTypeSetAmbiguityError>
pub fn check_type_set_ambiguity( &self, set_systems: &DagGroups<SystemSetKey, SystemKey>, ambiguous_with: &Graph<false, NodeId>, dependency: &Graph<true, NodeId>, ) -> Result<(), SystemTypeSetAmbiguityError>
Ensures that there are no edges to system-type sets that have multiple instances.