Struct SystemTypeSet
pub struct SystemTypeSet<T>(/* private fields */)
where
T: 'static;Expand description
A SystemSet grouping instances of the same function.
This kind of set is automatically populated and thus has some special rules:
- You cannot manually add members.
- You cannot configure them.
- You cannot order something relative to one if it has more than one member.