Enum ScheduleBuildError
#[non_exhaustive]pub enum ScheduleBuildError {
HierarchyLoop(String),
HierarchyCycle(String),
HierarchyRedundancy(String),
DependencyLoop(String),
DependencyCycle(String),
CrossDependency(String, String),
SetsHaveOrderButIntersect(String, String),
SystemTypeSetAmbiguity(String),
Ambiguity(String),
Uninitialized,
}Expand description
Category of errors encountered during schedule construction.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
HierarchyLoop(String)
A system set contains itself.
HierarchyCycle(String)
The hierarchy of system sets contains a cycle.
HierarchyRedundancy(String)
The hierarchy of system sets contains redundant edges.
This error is disabled by default, but can be opted-in using ScheduleBuildSettings.
DependencyLoop(String)
A system (set) has been told to run before itself.
DependencyCycle(String)
The dependency graph contains a cycle.
CrossDependency(String, String)
Tried to order a system (set) relative to a system set it belongs to.
SetsHaveOrderButIntersect(String, String)
Tried to order system sets that share systems.
SystemTypeSetAmbiguity(String)
Tried to order a system (set) relative to all instances of some system function.
Ambiguity(String)
Systems with conflicting access have indeterminate run order.
This error is disabled by default, but can be opted-in using ScheduleBuildSettings.
Uninitialized
Tried to run a schedule before all of its systems have been initialized.